@@ -4,12 +4,12 @@
 -- This is one version of this query. There is another version which may be faster.
 SELECT
   hash,
-  authored_timestamp_ms
+  authored_timestamp
 FROM
   DHtOp
 WHERE
-  DhtOp.authored_timestamp_ms >= :from
-  AND DhtOp.authored_timestamp_ms < :to
+  DhtOp.authored_timestamp >= :from
+  AND DhtOp.authored_timestamp < :to
   AND (
     storage_center_loc < :storage_end_loc
     OR storage_center_loc > :storage_start_loc
