@@ -2,12 +2,12 @@
 -- i.e. when :storage_start_loc <= :storage_end_loc
 SELECT
   hash,
-  authored_timestamp_ms
+  authored_timestamp
 FROM
   DHtOp
 WHERE
   DhtOp.when_integrated IS NOT NULL
-  AND DhtOp.authored_timestamp_ms >= :from
-  AND DhtOp.authored_timestamp_ms < :to
+  AND DhtOp.authored_timestamp >= :from
+  AND DhtOp.authored_timestamp < :to
   AND storage_center_loc >= :storage_start_loc
   AND storage_center_loc <= :storage_end_loc
