@@ -70,17 +70,17 @@ impl TestDbs {
     /// Create all three non-cell environments at once
     pub fn new(tempdir: TempDir) -> Self {
         use DbKind::*;
-        let conductor = DbWrite::new(&tempdir.path(), Conductor, DbSyncLevel::default()).unwrap();
-        let wasm = DbWrite::new(&tempdir.path(), Wasm, DbSyncLevel::default()).unwrap();
+        let conductor = DbWrite::new(tempdir.path(), Conductor, DbSyncLevel::default()).unwrap();
+        let wasm = DbWrite::new(tempdir.path(), Wasm, DbSyncLevel::default()).unwrap();
         let space = Arc::new(kitsune_p2p::KitsuneSpace(vec![0; 36]));
         let p2p_agent_store = DbWrite::new(
-            &tempdir.path(),
+            tempdir.path(),
             P2pAgentStore(space.clone()),
             DbSyncLevel::default(),
         )
         .unwrap();
         let p2p_metrics =
-            DbWrite::new(&tempdir.path(), P2pMetrics(space), DbSyncLevel::default()).unwrap();
+            DbWrite::new(tempdir.path(), P2pMetrics(space), DbSyncLevel::default()).unwrap();
         Self {
             conductor,
             wasm,
